@@ -23,7 +23,7 @@
 #include "reversebytearrayfilter.h"
 
 // Okteta core
-#include <abstractbytearraymodel.h>
+#include <okteta/abstractbytearraymodel.h>
 // KF5
 #include <KLocalizedString>
 
