@@ -22,10 +22,9 @@
 
 #include "abstracttoolwidget.h"
 #include "abstracttoolwidget_p.h"
-#include "abstracttoolwidget.moc"
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 AbstractToolWidget::AbstractToolWidget( QWidget* parent )
@@ -45,3 +44,6 @@ AbstractToolWidget::~AbstractToolWidget()
 }
 
 }
+
+//have to include this because of Q_PRIVATE_SLOT
+#include "moc_abstracttoolwidget.cpp"
